# usando a função de ajuste de curva
from numpy import array, polyfit, trapz, poly1d, linspace
from matplotlib import pyplot as p
import scipy.integrate as integrate

# nossos dados experimentais
x = array([1.1, 2.2, 3.3, 4.4, 5.5])
y = array([1.9, 5.8, 10.7, 15.3, 20.4])
# intervalo de valores teóricos de x para o gráfico
x2 = linspace(1.1, 5.5, 500)

# calculando os coeficientes
b, a = polyfit(x, y, 1)

# transformando os coeficientes em uma função
func = poly1d([b, a])
print('função proposta:', func)

# calculando a integral pelo método do trapézio do numpy
area1 = trapz(y,x)
msg = f'\n-Pelo método do trapézio, a área calculada é {area1:.3f}.'
print(msg)

area2 = integrate.quad(func, 1.1, 5.5)[0]
msg2 = f'\n-Pelo método quad, a área calculada é {area2:.3f}.'
print(msg2)

# plotando nossos dados e nossa equação em um gráfico 
p.clf()                                # limpando gráfico anterior
p.plot(x,y, 'bo', x2, func(x2), '-k')  # plotando o gráfico
p.title('Usando ajuste de curvas')     # título
p.xlabel('x')                          # legenda do eixo X
p.ylabel('y')                          # legenda do eixo Y
p.legend(['y', 'func'])                # legenda do gráfico
p.fill_between(x2, func(x2), color='lightgray')   # área
p.grid(color='k', linestyle='-', linewidth=0.1)   # linhas de grade
p.text(2, 2.5, 'Representação visual da integral')# comentário
p.show()                               # mostrando o gráfico

