# usando a função de ajuste de curva
# importando bibliotecas
from numpy import array, poly1d, flip, linspace
from numpy.polynomial import polynomial
from scipy.interpolate import UnivariateSpline
from scipy.interpolate import Akima1DInterpolator
import matplotlib.pyplot as p

# nossos dados experimentais
x = array([1, 2, 3, 4, 6, 7, 8, 10, 15, 25]) 
y = array([0.01, 0.5, 0.8, 2.6, 2.9, 6.15, 9.5, 12.2, 13.2, 13.4])
# gerando outros pontos teóricos de x para comparação
xs = linspace(1, 25, 1000)

# gerando a função de interpolação cúbica
fspline = UnivariateSpline(x,y)

# gerando a função de interpolação cúbica de Akima
fspline_akima = Akima1DInterpolator(x,y)

# usando o polifit do pacote polynomial do numpy
c, outros = polynomial.polyfit(x,y,2,full=True)
c = flip(c) # invertendo a ordem das constantes
# imprimindo resultados
print('c = ', c, 'outros=', outros)

# transformando os coeficientes angular e linear em uma função
func = poly1d(c)

# plotando nossos dados e nossa equação em um gráfico 
p.clf()                        # limpando gráfico anterior, se existir
p.plot(x,y, 'b*',  markersize=5)                 # plotando 1° gráfico
p.plot(xs, func(xs), '-k', linewidth=0.8)        # plotando 2° gráfico
p.plot(xs, fspline(xs), '--r', linewidth=1.2)    # plotando 3° gráfico
p.plot(xs, fspline_akima(xs), ':k', linewidth=1.5)# plotando 4° gráfico
p.title('Usando ajuste de curvas')               # título
p.xlabel('x')                                    # legenda do eixo X
p.ylabel('y')                                    # legenda do eixo Y
p.legend(['original', 'polinômio', 'spline', 'akima']) # legenda
p.grid(color='k', linestyle='-', linewidth=0.1)  # linhas de grade
p.show()                                         # mostrando o gráfico

