# importando bibliotecas
from scipy.optimize import minimize, fsolve, brute, fmin, broyden1, broyden2
from numpy import linspace, sin, sqrt
from matplotlib import pyplot as p

# declaração de função anônima
f = lambda x: 3*sin(x) - sqrt(x**2) + 1

# estimativas iniciais
x0 = 0; x1 = 5

# procurando x que resulte em f(x) mínimo (com a função minimize)
val = minimize(f, x0, method='Nelder-Mead', tol=1e-6)
print('-Pelo método minimize (mínimo local), o valor de x é:', val.x)
print('Para esse valor de x, f(x) =', f(val.x), '\n')

# procurando x que resulte em f(x) mínimo (com a função força bruta) 
val2 = brute(f, [(-16,20)], full_output=True, finish=fmin)
print('-Pelo método brute (minimo global), o valor de x é:', val2[0])
print('Para esse valor de x, f(x) =', f(val2[0]), '\n\n')

# intervalo de valores para x
x = linspace(-16, 20, 500)

# procurando as raízes
raizes = broyden1(f, [x0, x1])
print('-Pelo método broyden1, as raízes da função [x1, x2] são:', raizes)
print('Para as raízes encontradas, f(raizes) =', f(raizes))

raizes2 = broyden2(f, [x0, x1])
print('\n-Pelo método broyden2, as raízes da função [x1, x2] são:', raizes2)
print('Para as raízes encontradas, f(raizes2) =', f(raizes2))

raizes3 = fsolve(f, [x0, x1])
print('\n-Pelo método fsolve, as raízes da função [x1, x2] são:', raizes3)
print('Para as raízes encontradas, f(raizes) =', f(raizes3))

# plotando os resultados
p.clf()
p.plot(x, f(x), '-b')
p.xlabel('x')                                   # legenda do eixo X
p.ylabel('f(x)')                                # legenda do eixo Y
p.grid(color='k', linestyle='-', linewidth=0.1) # linhas de grade
p.show()                                        # mostrando o gráfico

