"""
Dados termodinâmicos e parâmetros para:
    propano, 
    nButano, 
    nPentano, 
    nHexano, 
    hHeptano e
    tolueno
    Para outros dados, consulte KUKREJA, Naman et al. 
    Cubic equation of state as a quartic in disguise. 
    Fluid Phase Equilibria, v. 531, p. 112908, 2021.
    Tabelas C1 e C2.
"""
 # dicionário de propriedades das subestâncias
dados = {'propano':{'Tc':369.83, 'Pc': 4.248e6, 'm':-0.26408, 'n':0.15190},
        'nButano':{'Tc':425.12, 'Pc': 3.796e6, 'm':-0.17448, 'n':0.17998},
         'nPentano':{'Tc':469.7, 'Pc': 3.37e6, 'm':-0.22855, 'n':0.18959},
         'nHexano':{'Tc':507.6 , 'Pc': 3.025e6, 'm':-0.20310, 'n':0.21660},
         'nHeptano':{'Tc':540.2, 'Pc': 2.74e6, 'm':-0.22233, 'n':0.22805},
         'tolueno':{'Tc':591.75, 'Pc': 4.108e6, 'm':-0.22807, 'n':0.19542}} 

Oms = {'propano':{'Oma':0.53352,'Omb':0.09125,'Omc':0.32551,'Omd':-0.07501,'Ome':9.46317e-6,'Omf':-0.26324},
       'nButano':{'Oma':0.53438,'Omb':0.09051,'Omc':0.32765,'Omd':-0.07441,'Ome':1.64067e-5,'Omf':-0.25873},
       'nPentano':{'Oma':0.54589,'Omb':0.08935,'Omc':0.34850,'Omd':-0.07541,'Ome':5.70335e-8,'Omf':-0.26374},
       'nHexano':{'Oma':0.54618,'Omb':0.08658,'Omc':0.35168,'Omd':-0.07266,'Ome':3.89985e-6,'Omf':-0.25645},
       'nHeptano':{'Oma':0.55506,'Omb':0.08604,'Omc':-0.07352,'Omd':0.36685,'Ome':4.08173e-6,'Omf':-0.25129},
       'tolueno':{'Oma':0.54671,'Omb':0.08723,'Omc':0.35166,'Omd':-0.07335,'Ome':2.23797e-6,'Omf':-0.24708}}    


# funções extratoras
def Composto(substancia):

    return DadosComposto(**dados[substancia])
# funções extratoras
def DadosComposto(Tc, Pc, m, n):
    return [Tc, Pc, m, n]

# funções extratoras
def OmComposto(substancia):

    return OmParametros(**Oms[substancia])

def OmParametros(Oma, Omb, Omc, Omd, Ome, Omf):
    return [Oma, Omb, Omc, Omd, Ome, Omf]

