# importando bibliotecas 
from sympy import Symbol, solve
from numpy import exp
import dados_cap14 as fdata
# exemplo de aplicação para propano
# condições operacionais
T = 350                         # temperatura absoluta (K)
p = 1.013e6                     # pressão de trabalho atual (Pa)
R = 8.314462                    # constante dos gases (J/mol.K)
# carregamento dos dados da substância escolhida
substancias = [ 'propano', 'nButano', 'nPentano',
               'nHexano', 'nHeptano', 'tolueno']
substancia = substancias[0]
[Tc, Pc, m, n] = fdata.Composto(substancia)
# calculado a temperatura reduzida - Equação 14.9
Tr = T/Tc                             
# avaliando continuidade do método
if Tr >= 0.5 and Tr <= 0.99:
    # carregando dados da substância escolhida
    (Oma, Omb, Omc, Omd, Ome, Omf) = fdata.OmComposto(substancia)
    
    a = (Oma*(R*Tc)**2)/Pc                #Equação 14.2
    b = Omb*R*Tc/Pc                       #Equação 14.3
    c = Omc*R*Tc/Pc                       #Equação 14.4
    d = Omd*R*Tc/Pc                       #Equação 14.5
    e = Ome*R*Tc/Pc                       #Equação 14.6
    f = Omf*R*Tc/Pc                       #Equação 14.7
    alfa = exp((1+Tr**m)*(1-Tr**n))       #Equação 14.8
    # declaração da variável simbólica
    v = Symbol('v')
    # equação de Estado Quadrática         #Equação 14.1
    func = ((R*T)/(v-b))*(1+ e/(v+f)) - a*alfa/((v+c)*(v+d)) - p
    # resolvendo a equação com o solve
    raizes = solve(func, v)
    # imprimindo os resultados
    print(f'O volume específico v calculado foi {raizes[1]*1000:.2f} L/mol.')
else:
    print(f'Método válido apenas se 0,50 <= Tr <= 0,99. Tr={Tr: .3f}.')
    print('Verifique os valores de T e Tc e tente novamente.')
    
    