# importando bibliotecas
import ternary
import pandas as pd
from numpy import transpose as transp, array as a

# lendo dados da planilha
dados=pd.read_excel('dadosTernarios.xlsx')

# adequando a posição dos dados
dados= transp(a([dados['Acetato de Etila'],
                 dados['Acetona'],
                 dados['Água']]),(1,0))

# definindo escala de cada eixo ternário (et)
escala = 100
figura, et = ternary.figure(scale=escala)

# editando as linhas das bordas 
et.boundary(linewidth=1.0)
# editando as linhas de grade 
et.gridlines(color="blue", multiple=5, linewidth=0.15)

# ajustando texto do título e dos eixos 
tamFonte = 12
distEixo=0.1
et.set_title("Diagrama Ternário \n\n", 
             fontsize=tamFonte, 
             color="blue")

# nomeando, definindo tamanho de fonte e distância dos vértices
et.right_corner_label("Acetato", fontsize=tamFonte, offset=0.017)
et.top_corner_label("Acetona", fontsize=tamFonte, offset=0.2)
et.left_corner_label("Água", fontsize=tamFonte, offset=0.017)

# ajustando distância dos marcadores de escala
et.ticks(axis='lbr',       #l-esquerda b-base e r-direita
         multiple=10,      #múltiplos de 10
         linewidth=0.5,    #espessura de linha
         offset=0.017,     #distância do marcador
         clockwise=True)   #sentido horário 

# plotando a curva terária
et.plot(dados, marker='o', #estilo do marcador
           linestyle='-',  #estilo da linha
           linewidth=0.5,  #espessura de linha
           color='black',  #cor da linha e texto
           label='\nAcetona\nÁgua\nAcetato de Etila')
et.legend() # mostrando a legenda no gráfico

# removendo a escala e os eixos padrões do matplotlib
et.get_axes().axis('off')

figura.show() # mostrando a figura


# -*- coding: utf-8 -*-
"""
Created on Fri Jul 22 10:28:05 2022
https://github.com/marcharper/python-ternary
https://morioh.com/p/86163444d5b7
Marc Harper et al. (2015). python-ternary: Ternary Plots in Python. Zenodo. 10.5281/zenodo.594435
como instalar:
    Open Anaconda.
    Select Environments in the left hand pane below home.
    Just to the right of where you selected and below the "search environments" bar, you should see base(root). Click on it.
    A triangle pointing right should appear, click on it an select "open terminal"
    Use the regular pip install command here.
    Copie e cole a linha de código a seguir e, em seguida, aperte "Enter" e aguarde:
        pip install python-ternary
    
    última linha de código removida antes de et.get_axes().axis('off'): 
        et.clear_matplotlib_ticks()
"""