# importando bibliotecas
import ternary
import pandas as pd
from numpy import transpose as transp, array as a
from scipy import linalg
# lendo dados da planilha
dados=pd.read_excel('dadosTernarios.xlsx','Sheet1')

# adequando a posição dos dados
dados= transp(a([dados['Acetato de Etila'],
                 dados['Acetona'],
                 dados['Água']]),(1,0))

# definindo escala de cada eixo ternário (et)
escala = 100
figura, et = ternary.figure(scale=escala)

# editando as linhas das bordas 
et.boundary(linewidth=1.0)
# editando as linhas de grade 
et.gridlines(color="blue", multiple=5, linewidth=0.15)

# ajustando texto do título e dos eixos 
tamFonte = 12
distEixo=0.1
et.set_title("Diagrama Ternário \n\n", 
             fontsize=tamFonte, 
             color="blue")

# nomeando, definindo tamanho de fonte e distância dos vértices
et.right_corner_label("Acetato", fontsize=tamFonte, offset=0.017)
et.top_corner_label("Acetona", fontsize=tamFonte, offset=0.2)
et.left_corner_label("Água", fontsize=tamFonte, offset=0.017)

# ajustando distância dos marcadores de escala
et.ticks(axis='lbr',       # l-esquerda b-base e r-direita
         multiple=10,      # múltiplos de 10
         linewidth=0.5,    # espessura de linha
         offset=0.017,     # distância do marcador
         clockwise=True)   # sentido horário 

# plotando a curva terária
et.plot(dados, marker='o', # estilo do marcador
           linestyle='-',  # estilo da linha
           linewidth=0.5,  # espessura de linha
           color='black',  # cor da linha e texto
           label='\nAcetona\nÁgua\nAcetato de Etila')
et.legend() # mostrando a legenda no gráfico

# removendo a escala e os eixos padrões do matplotlib
et.get_axes().axis('off')

# o código figura.show() desta linha foi movida para a linha 78
# Aplicando a reta QcSc ao diagrama
# posição dos pontos (acetato, acetona, água)
Qc = a([0.0, 26.0, 74.0])  # percentual mássico da alimentação
Sc = a([100.0, 0.0, 0.0])  # percentual mássico do solvente
Mc = a([30.0, 18.2, 51.8]) # percentual mássico da mistura

pontos = [Qc,Sc]           # pontos da reta QcSc
# plotando a reta
et.plot(pontos,
        marker='h',        # marcador tipo hexágono
        color='blue',      # na cor azul
        linewidth=0.4)     #espessura de linha
# escrevendo os nomes dos pontos Qc e Sc na reta
et.annotate('Qc', a([1.0, 26.5, 74.0]))
et.annotate('Sc', a([101.0, 0.0, 0.0]))

# plotanto o ponto Mc
et.scatter(a([Mc]), 
           marker='D',     # marcador tipo diamante
           color='red')    # na cor vermelha
# escrevendo o nome do ponto Mc na reta
et.annotate('Mc', Mc+1)

# mudando a cor de fundo do diagrama ternário
et.set_background_color('darkorange')

# o código figura.show() desta linha foi movida para a linha 78
# Aplicando a reta RcEc ao diagrama
# posição dos pontos (acetato, acetona, água)
Rc = a([7.5, 1.5, 91.0])    # percentual mássico da alimentação
Ec = a([51.5, 33.5, 15.0])  # percentual mássico do solvente

pontos2 = [Rc,Ec]           # pontos da reta QcSc
# plotando a reta
et.plot(pontos2,
        linestyle='--',     #estilo da linha
        marker='h',         # marcador tipo hexágono
        color='darkblue',   # na cor azul
        linewidth=0.5)      #espessura de linha
# escrevendo os nomes dos pontos Qc e Sc na reta
et.annotate('Rc', a([3.0, 2.5, 96.0]))
et.annotate('Ec', a([52.0, 34.0, 12.0]))

figura.show()               # mostrando a figura

# defindindo os valores de A e b para Ax = b 
A = a([[1.0, 1.0],          # Constantes da Equação 14.52  
     [0.015, 0.335]])       # Constantes da Equação 14.53 
b = a([[500], [91]])        # Resultados das Equações 14.52 e 14.53 

 # obtendo os valores de x (R e E)
[R, E] = linalg.solve(A, b) # x = A\b
# imprimindo os resultados
msg = 'Para a presente aplicação, temos '
msg = msg + f'R ={R[0]:.1f}kg/h e E ={E[0]:.1f}kg/h.'
print(msg)







# -*- coding: utf-8 -*-
"""
Created on Fri Jul 22 10:28:05 2022
https://github.com/marcharper/python-ternary
https://morioh.com/p/86163444d5b7
Marc Harper et al. (2015). python-ternary: Ternary Plots in Python. Zenodo. 10.5281/zenodo.594435
como instalar:
    Open Anaconda.
    Select Environments in the left hand pane below home.
    Just to the right of where you selected and below the "search environments" bar, you should see base(root). Click on it.
    A triangle pointing right should appear, click on it an select "open terminal"
    Use the regular pip install command here.
    Copie e cole a linha de código a seguir e, em seguida, aperte "Enter" e aguarde:
        pip install python-ternary
    
    última linha de código removida antes de et.get_axes().axis('off'): 
        et.clear_matplotlib_ticks()
"""