# importando bibliotecas
from scipy.optimize import fsolve
from numpy import exp
import dados_cap14 as fdata
# exemplo de aplicação para propano
def func(v, R, T, a, b, c, d, e, p, Tr):
    
    alfa = exp((1+Tr**m)*(1-Tr**n))            # Equação 14.8
    return (((R*T)/(v-b))*(1+ e/(v+f)) - a*alfa/((v+c)*(v+d)) - p)

# declaração de variáveis  
substancias = [ 'propano', 'nButano', 'nPentano',
               'nHexano', 'nHeptano', 'tolueno']
substancia = substancias[0]
# carregando informações do banco de dados [Tc(K); Pc(Pa)]
[Tc, Pc, m, n] = fdata.Composto(substancia)

#condições operacionais
T = 350                         # temperatura absoluta (K)
p = 1.013e6                     # pressão de trabalho atual (Pa)
R = 8.314462                    # constante dos gases (J/mol.K)
# calculado a temperatura reduzida - Equação 14.9
Tr = T/Tc
# avaliando continuidade do método
if Tr >= 0.5 and Tr <= 0.99:
    # carregando dados da substância escolhida
    (Oma, Omb, Omc, Omd, Ome, Omf) = fdata.OmComposto(substancia)
    #calculando os valores dos parâmetros
    a = (Oma*(R*Tc)**2)/Pc                # Equação 14.2
    b = Omb*R*Tc/Pc                       # Equação 14.3
    c = Omc*R*Tc/Pc                       # Equação 14.4
    d = Omd*R*Tc/Pc                       # Equação 14.5
    e = Ome*R*Tc/Pc                       # Equação 14.6
    f = Omf*R*Tc/Pc                       # Equação 14.7
    # resolução utilizando a função fsolve
    sol = fsolve(func, args=(R, T, a, b, c, d, e, p, Tr), x0 = 0.05)
    # imprimindo os resultados
    print(f'O volume específico v calculado foi {sol[0]*1000:.3f}L/mol.')
else:      
    print(f'Método válido apenas se 0,50 <= Tr <= 0,99. Tr={Tr: .3f}.')
    print('Verifique os valores de T e Tc e tente novamente.')

