# importando bibliotecas
from numpy import array
from scipy.optimize import minimize
from funcs_otto import *
# declaração dos limites (variável = [inferior,superior])
Fa = [12200.0, 14600.0]
Fb = [28000.0, 32000.0]
Fr = [160000.0, 330000.0]
Fra = [17000.0, 38000.0]
Frb = [68000.0, 120000.0]
Frc = [3000.0, 7500.0]
Fre = [13500.0, 137000.0]
Frp = [10000.0, 19000.0]
Fg = [2500.0, 3700.0]
Fp = [4762.9, 4763.0]
Fd = [33000.0, 4600000.0]
T = [580.0, 680.0]
V = [60.0, 60.01]

limites = [Fa, Fb, Fr, Fra, Frb, Frc,
           Fre, Frp, Fg, Fp, Fd, T, V]
# estimativas iniciais
x0 = []
for limite in limites: x0.append(limite[0]*2)
# definição das restrições que serão usadas na função minimize
cons = [{'type':'eq', 'fun': g1},{'type':'eq', 'fun': g2},
        {'type':'eq', 'fun': g3},{'type':'eq', 'fun': g4},
        {'type':'eq', 'fun': g5},{'type':'eq', 'fun': g6},
        {'type':'eq', 'fun': g7},{'type':'eq', 'fun': g8},
        {'type':'eq', 'fun': g9}]
# chamando a função minimize para resolver o problema
solucao = minimize(func_objetivo, x0, bounds = limites,
                   method='SLSQP',constraints=cons,
                   options={'maxiter':1000,'ftol':1e-08})
# carregando os valores ótimos de Fa, Fb...T que maximizam o % I
x = solucao.x
print(f'\nO valor % do retorno é de {-func_objetivo(x): .3f}')
# imprimindo a solução
variaveis = ['Fa', 'Fb', 'Fr', 'Fra', 'Frb', 'Frc',
             'Fre', 'Frp', 'Fg', 'Fp', 'Fd', 'T', 'V']
unidades = 11*['lb/h'] + ['°R', 'ft3']
print('O valor ótimo encontrado para cada variável é:')
for i in range(len(variaveis)):
    print(variaveis[i], f'={x[i]: ,.3f}', unidades[i])
# se a solução foi alcançada...
if bool(solucao.success):
    print('\nAs restrições foram satisfeitas!',
          '\nA soma dos quadrados dos desvios das restrições é:',
          f'\nS2 = {squadrado(x):.3E}')
else: #caso contrário, imprima as violações
    funcs = [g1(x),g2(x),g3(x),g4(x),
             g5(x), g6(x),g7(x), g8(x), g9(x)]
    funcNomes = ['g1', 'g2', 'g3', 'g4',
                 'g5', 'g6', 'g7', 'g8', 'g9']
    print('Mas as restrições NÃO foram alcançadas!')
    for i in range(len(funcNomes)):
        if abs(funcs[i]) > 1e-5:
            print('Esta aqui Não foi --v')
        print(funcNomes[i],'=',f'{funcs[i]: ,.3f}')

