# importando bibliotecas
from numpy import array
import matplotlib.pyplot as p
from scipy.optimize import minimize
from scipy.integrate import solve_ivp
from scipy.interpolate import CubicSpline

# declaração das EDOs
def EDOs(tau, C0):
    # constantes de velocidade
    k1 = 55.2                                   #Eq. 16.65
    k2 = 30.2                                   #Eq. 16.66
    # declaração das variáveis
    Ch, Cm, Cx = C0
    # cálculo das EDOs
    dChdtau = -k1*(Ch**0.5)*Cm - k2*Cx*Ch**0.5  #Eq. 16.62
    dCmdtau = -k1*(Ch**0.5)*Cm                  #Eq. 16.63
    dCxdtau = k1*(Ch**0.5)*Cm - k2*Cx*Ch**0.5   #Eq. 16.64
    # retornando os resultados das EDOs
    return array([dChdtau, dCmdtau, dCxdtau])

# Condições iniciais do hidrogênio, mesitileno e m-xileno
Ch0, Cm0, Cx0 = 0.021, 0.0105, 0.0

# intervalo do tempo espacial
tau = [0, 1]
# resolvendo o sistema ODE, default method='RK45'
sol = solve_ivp(EDOs, tau, [Ch0, Cm0, Cx0], max_step = 0.01)
print(sol)    # impressão do relatório de solução das EDOs
# dados oriundos do solve
t = sol.t                   # valores de tau
Ch = sol.y[0]               # concentração de hidrogênio
Cm = sol.y[1]               # concentração de mesitileno
Cx = sol.y[2]               # concentração de m-xileno
# obtendo uma equação para otimização
Eq = CubicSpline(t, Cx)     # interpolando os dados do m-xileno
def EqMxi(t):               # necessária para inversão do sinal
    res = Eq(t)
    return -res
# obtendo tau para a maior produção de m-xileno
solOpt = minimize(EqMxi, x0=0.05, bounds =[[0.0, 0.5]])
print(solOpt)               #impressão do relatório otimização
xmelhor = solOpt.x[0]       # melhor valor de tau
ymelhor = Eq(xmelhor)       # produção máxima de m-xileno
# plotando o gráfico
p.clf()
# multiplicamos por 100 para melhor visualização
p.plot(t, 100*Ch, '-g', t, 100*Cm, '--r',
       t, 100*Cx, '-.b', xmelhor, 100*ymelhor, 'ok')
p.xlabel(r'$\tau$(h)', fontsize = 12) #imprime a letra grega tau
p.ylabel('Concentração (lb mol/ft3) x 100')
p.legend(['Ch', 'Cm', 'Cx',r'$\tau$ Ótimo'],prop={'size': 12})
p.show()

