# importando bibliotecas
from numpy import array, zeros
from scipy.optimize import fsolve
from tabulate import tabulate
#declaração da Equação de Rachford-Rice
def RachfordRice(v, z, K):
    # iniciando um vetor de zeros
    fv = zeros(len(z))
    for i in range(len(z)):
        # calculando a Equação 15.14 para cada componente i
        fv[i] = (z[i]*(K[i]-1))/((K[i]-1)*v + 1)
    return sum(fv) # retornando o somatório da Eq. 15.14

# descrição dos componentes
componentes = ['propano', 'n-butano', 'n-pentano', 'n-octano']
# frações molares da alimentação
zi = array([0.1, 0.3, 0.4, 0.2])
# valores das constantes de equilíbrio
Ki = array([6.8, 2.2, 0.8, 0.052])
# calculando o valor de v'
v = fsolve(RachfordRice, args=(zi,Ki), x0=0.1)[0]
# avaliando o resultado obtido
if v >= 0 and v <= 1:
    # imprimindo o valor da raiz (v)
    print(f"Resultado de v' = {v:3.3f}.")
    # inicializando os valores de xi e yi  
    x = zeros(len(zi))
    y = zeros(len(zi))
    # calculando as frações molares nas 
    # correntes de topo e da base do flash
    for i in range(len(zi)):
        x[i] = (zi[i])/((Ki[i]-1)*v + 1) # Eq. 15.13
        y[i] = Ki[i]*x[i]                # Eq. 15.4
    # imprimindo resultados
    titulos = ['componentes','xi', 'yi']
    print('\nA seguir os dados de composição de xi e yi:')
    print(tabulate(list(zip(componentes,x,y)),headers=titulos,
                   tablefmt='grid', numalign='center',
                   floatfmt=('.3f', '.3f', '.3f')))
else: # algo deu errado
    msg = 'O programa não encontrou solução.'
    msg = msg + '\nReveja os dados de entrada.'
    print(msg)

    
    
