# importando bibliotecas
from tabulate import tabulate
from numpy import array, zeros
from scipy.optimize import fsolve
import flash_Lee_Kesler as flash
# condições de operação
T = 35 + 273.15                      # °C --> K
P = 28.                              # bar
componentes=['Etileno', 'Etano', 'Propano'] # posição
zi = array([0.35, 0.25, 0.4])        # fração molar
Tc = array([282.35, 305.34, 369.85]) # K - temperatura crítica
Pc = array([50.40, 48.714, 42.48])   # bar - pressão crítica   
Tn = array([169.4, 184.6, 231.1])    # K - temperatura normal ebulição
# cálculo das pressões de vapor das substâncias
Psati = zeros(len(zi))               # Pressão de  saturação(bar)
for i in range(len(zi)):
    Psati[i]=flash.Psat(T, Tc[i], Tn[i], Pc[i])         #Eq. 15.21
# cálculo do Ponto de Bolha
Pbol = flash.Pboli(zi, Psati) # bar                     #Eq. 15.22
print(f'Pressão do ponto de bolha da mistura: {Pbol:.2f}bar')
# cálculo do Ponto de Orvalho 
Porv = flash.Porvi(zi,Psati)  # bar                     #Eq. 15.23
print(f'Pressão do ponto de orvalho da mistura:  {Porv:.2f}bar')
# cálculo dos valores Ki
K = flash.Ki(zi, Psati, P)                              #Eq. 15.24 
# calculando o valor de v'
v = fsolve(flash.RachfordRice, args=(zi,K), x0=0.1)[0]  #Eq. 15.14
# avaliando o resultado obtido
if v >= 0 and v <= 1:
    # imprimindo o valor da raiz (v)
    print(f"Resultado de v' = {v:3.3f}.")
    # inicializando os valores de xi e yi  
    x = zeros(len(zi)); y = zeros(len(zi))
    # frações molares nas correntes de topo e da base do flash
    [x, y] = flash.compXY(zi, K, v)             #Eqs. 15.13 e 15.4 
    # imprimindo resultados
    titulos = ['componentes','xi', 'yi', 'Ki']
    print('\nA seguir os dados de composição de xi e yi:')
    print(tabulate(list(zip(componentes, x, y, K)),headers=titulos,
                   tablefmt='grid', numalign='center',
                   floatfmt=('.3f', '.3f', '.3f', '.3f')))
else: # algo deu errado
    msg = 'O programa não encontrou solução.'
    msg = msg + '\nReveja os dados de entrada.'
    print(msg)


  #Cálculo da composição das correntes de vapor e de líquido de um Flash
'''
Critical constants and acentric factors for long-chain alkanes suitable for
corresponding states applications. A critical review Chemical Engineering 
Journal 66 ( 1997) 35-49
'''  
#Nc = 3 #número de carbonos
#  # Para n-alcanos, temos:
#Tb = 369.8*((1.242 + 0.138*Nc)/(2.242 + 0.138*Nc))
#print('temperatura calculada=',Tb, '\ntemperatura normal=', 231.1)
#
#Tb = 369.8*(0.567 + 0.02*Nc - (0.02*Nc)**2)
#print('temperatura calculada=',Tb, '\ntemperatura normal=', 231.1)
#
#Tb = 369.8/(0.584 + 0.965*(2*0.0141 + (Nc-2)*0.0189)+(2*0.0141+(Nc-2)))
#print('temperatura calculada=',Tb, '\ntemperatura normal=', 231.1)

'''
Dados de Pc (bar) e Tc(K) do trabalho de
EQUATION OF STATE IN THE ACENTRIC FACTOR SYSTEM
Fluid Phase Equilibria, 46 (1989) 113-130
Elsevier Science Publishers B.V., Amsterdam - Printed in The Netherlands

Dados de Tn (K) em
SMITH, J. M.; VAN NESS, H. C.; ABBOTT, M. M. Introdução à Termodinâmica 
da Engenharia Química, 7ª edição. LTC, Rio de Janeiro, v. 200, 2007.
'''