# importando bibliotecas
from numpy import exp, log, array, zeros
print()
# declaração da Equação de Pitzer aplicada a Lee-Kesler
def Pitzer(Tr): #Tr é a temperatura reduzida em bar
    f0 = 5.92714 - 6.09648/Tr - 1.28862*log(Tr) + 0.169347*(Tr**6)
    f1 = 15.2518 - 15.6875/Tr - 13.4721*log(Tr) + 0.43577*(Tr**6)
    return array([f0, f1])

# declaração da função do cálculo do fator acêntrico
# temp normal (K), temp crítica (k) e pressão crítica  (bar)
def acentric(Tn, Tc, Pc, imprimir_fator_acentrico = False):  
    Trn = Tn/Tc                   # temperatura normal reduzida
    Prn = 1.01325/Pc              # Pressão normal reduzida em bar
    [f0w, f1w] = Pitzer(Trn)      # chamada da equação de Pitzer 
    omega = (log(Prn) - f0w)/f1w  # cálculo do fator acêntrico
    if imprimir_fator_acentrico:
        print(f'O fator acêntrico para o composto é {omega:.4f}.')
    return omega

# declaração da função do cálculo da pressão de saturação
def Psat(T, Tc, Tn, Pc, imprimir_fator_acentrico = False):
    #Lee-Kesler
    Tr = T/Tc                     # temperatura  reduzida em K
    [f0, f1]  = Pitzer(Tr)
    omega = acentric(Tn, Tc, Pc, imprimir_fator_acentrico)
    lnPrsat = f0 + omega*f1
    prsat = exp(lnPrsat)          # Pressão de saturação em bar
    psat = prsat*Pc               # bar 
    return psat

#declaração da Equação de Rachford-Rice
def RachfordRice(v, z, K):
    # iniciando um vetor de zeros
    fv = zeros(len(z))
    for i in range(len(z)):
        # calculando a Equação 15.14 para cada componente i
        fv[i] = (z[i]*(K[i]-1))/((K[i]-1)*v + 1)
    return sum(fv) # retornando o somatório da Eq. 15.14

# cálculo do Ponto de Bolha
def Pboli(zi, Psat):
    pbol = 0.0
    for i in range(len(zi)):
        pbol = pbol + zi[i]*Psat[i]     # bar
    return pbol

# cálculo do Ponto de Orvalho 
def Porvi(zi, Psat):
    try:
        porv = 0.0
        for i in range(len(zi)):
            porv = porv + zi[i]/Psat[i]    
        porv = 1/porv
    except ZeroDivisionError:
        print('Divisão por zero no cálculo da Pressão de Orvalho.')
        porv = 0
    return porv

# cálculo dos valores Ki
def Ki(zi, Psat, P):
    K = zeros(len(zi))
    for i in range(len(zi)):
        K[i] = Psat[i]/P
    return K

# cálculo das frações molares
def compXY(zi, K, v):
    # inicializando os valores de xi e yi  
    x = zeros(len(zi)); y = zeros(len(zi))
    # frações molares nas correntes de topo e da base do flash
    for i in range(len(zi)):
        x[i] = (zi[i])/((K[i]-1)*v + 1) # Eq. 15.13
        y[i] = K[i]*x[i]
    return [x, y]

