# importando bibliotecas
import pandas as pd
from time import sleep
from numpy import array as a
from numpy import concatenate
import matplotlib.pyplot as p
import funcs_Cartas_cap_16 as c
from numpy.random import uniform, random
import Eqs_estatistica_cap16 as f
from testes_regras_carta import testeregra1, testeregra2
from testes_regras_carta import testeregra3, testeregra4, relatorioCarta

#----------------PARTE 1: CÁLCULO DAS ESTATÍSTICAS----------------------
# carregamento dos dados de temperatura (Tabela 16.6)
Dados = pd.read_excel('dados_temp_cap16.xlsx')
# transformando dados em uma lista do python
temperaturas = Dados.values.tolist()
# calculando a média
medias = f.media1barra(temperaturas)     # Eq. 16.8
# calculando a amplitude R
amplitudes = f.amplitudeR(temperaturas)  # Eq. 16.10
# calculando o desvio
desvio_pads = f.desvioPA(temperaturas)   # Eq. 16.12
# calculando a média das médias
media2b = f.media2barras(medias)         # Eq. 16.9
# calculando a média da amplitude R
amplitude_media = f.mediaAmplitudeR(amplitudes)  # Eq. 16.11
# calculando a média dos desvios
desvio_pad_medio = f.mediaDesvioPA(desvio_pads)  # Eq. 16.13

# obtendo a quantidade de replicatas (n) e de amostras (m)
n = len(temperaturas[0]); m = len(temperaturas)
x = list(range(1,m+1))                   # n° da amostra

repeticoes = 1                           # contador
passo = list(range(min(x), max(x)+1, 3)) # escala eixo x das cartas
#----------------PARTE 2: CONSTRUÇÃO DAS CARTAS DE CONTROLE------------
# calculo dos limites da carta de controle XR
[LSC, LC, LIC] = c.cartaXRmedias(media2b,amplitude_media, n, m)
[LSCr, LCr, LICr] = c.cartaXRamplitudes(amplitude_media, n, m)
# calculo dos limites da carta de controle XS
[LSCm, LCm, LICm] = c.cartaXSmedias(media2b,desvio_pad_medio, n, m)
[LSCs, LCs, LICs] = c.cartaXSdesvio(desvio_pad_medio, n, m)
    
# testando as regras de controle
regra1 = testeregra1(LSC[0], LC[0], LIC[0], medias)
regra2 = testeregra2(medias)
regra3 = testeregra3(LC[0], medias)
regra4 = testeregra4(medias)
regras = [regra1, regra2, regra3, regra4]

while repeticoes <= 50:    
    # plotando os gráficos
    p.clf()          # limpando gráfico anterior
    #----------formatação e plotagem do gráfico 1------------#                                       
    p.subplot(2,2,1) # n° de gráficos e posição do gráfico da média 
    p.plot(x, medias[-m:], '-*k', x, LC, '-b', x, LSC, '-r', x, LIC,'-r')                               
    p.title('Carta X-R - Médias')                    # título
    p.xlabel('Amostras')                             # legenda do eixo X
    p.xticks(passo)
    p.ylabel('Médias')                               # legenda do eixo Y
    p.grid(color='k', linestyle='-', linewidth=0.1)  # linhas de grade
    
    #----------formatação e plotagem do gráfico 2------------#
    p.subplot(2,2,2) # definindo a posição do gráfico da amplitude
    p.plot(x,amplitudes[-m:], '-*k',x, LCr,'-b',x, LSCr, '-r', x,LICr,'-r')                               
    p.title('Carta X-R - Amplitudes')                # título
    p.xlabel('Amostras')                             # legenda do eixo X
    p.xticks(passo)    
    p.ylabel('Amplitude')                            # legenda do eixo Y
    p.grid(color='k', linestyle='-', linewidth=0.1)  # linhas de grade
    
    # --------Imprimindo as mensagens das Regras de controle-------#
    p.subplot(2,1,2)
    num_msg = 1  
    controle = True
    p.axis([0, 80, 0, 20])           # definição da escala     
    for regra in regras:
        if regra[0] != 'Planta sob controle estatístico.':
            controle = False
            for i in range(len(regra)-1, -1, -1):
                num_msg += 2
                p.text(1, num_msg, regra[i], fontsize= 9, color='red')        
    if num_msg > 20: p.axis([0, 80, 0, num_msg+5])
    if controle :
        msg = 'Planta sob controle estatístico.'
        p.text(1, 9, msg, fontsize= 9, color='blue') # texto em azul

    p.xticks([])  # ocultando a escala do eixo x 
    p.yticks([])  # ocultando a escala do eixo y 
    p.title('Resultados dos Testes')

    p.tight_layout()  # ajustando automaticamente o gráfico na figura
    p.show()          # mostrando a figura com a carta
    p.pause(0.05)     # pausando plotagem para atualização dos dados
    
    #----coleta de uma nova amostra (Simulação do processo) ----------#
    if random(1) < 0.9:
        # distúrbio
        amostra = a(uniform(low=LIC[0],high=LSC[0],size=[1, n])) 
    else:
        # estacionário
        amostra = a(uniform(low=LIC[0]-1.5,high=LSC[0]+1.5,size=[1, n]))
   
    #----------------Tratamento da amostra ----------------------- ---#
    # calculando a média
    media = f.media1barra(amostra)     # Eq. 16.8
    # concatenando a nova média às antigas
    medias = concatenate((medias, media), axis=0)
    # calculando a amplitude R
    amplitude = f.amplitudeR(amostra)  # Eq. 16.10    
    # concatenando a nova amplitude às antigas
    amplitudes = concatenate((amplitudes, amplitude), axis=0)

    total = len(medias)
    x = list(range(1,total+1))[-m:]
    passo = list(range(min(x), max(x)+1, 3))  # escala eixo x das cartas
    #----------------Teste das Regras de Controle----------------------#    
    regra1 = testeregra1(LSC[0], LC[0], LIC[0], medias)  # teste regra 1
    regra2 = testeregra2(medias)                         # teste regra 2
    regra3 = testeregra3(LC[0], medias)                  # teste regra 3
    regra4 = testeregra4(medias)                         # teste regra 4
    regras = [regra1, regra2, regra3, regra4]
    #--------------Imprimindo resultados no console--------------------#
    print(f'\ncomportamento da amostragem {repeticoes}')
    print(amostra)             # imprimindo os últimos 5 dados coletados
    repeticoes+= 1             # atualizando contadores
    sleep(1)  # pausando a execução do programa (aumenta a realidade :D)
#-----------------------Impressão de resultados-------------------------
imprimir_relatorio = True
print()
if imprimir_relatorio: # impressão do resumo do comportamento das cartas
    relatorioCarta(LSC, LC, LIC, medias)
print('\nFim da simulação. :D')

