# importando bibliotecas
import numpy as np
import matplotlib.pyplot as p

# declaração de variáveis
mi = 0.89e-3           # viscosidade dinâmica do fluido - Pa.s = kg/m.s
v = 4.5                # velocidade média do fluido - m/s
D = 3/100              # diâmetro do tubo - m
ro = 997.05            # massa específica - kg/m3
f = 0                  # fator de atrito estimado
epsilon = 4.57e-5      # rugosidade do tubo (m)
L = 15                 # comprimento do tubo (m)
f1 = 100               # fator de atrito calculado
n = 0                  # estimativa inicial do contador
erro = 1e-2            # estimativa inicial do erro absoluto

# cálculo do número de Reynolds
Re = ro*D*v/mi         # Eq. 6.1 

# realizando os testes para a determinação do regime
if Re <= 2300.0:
    msg = 'laminar'
elif Re > 2300.0 and Re <= 4000.0:
    msg = 'transiente'
else:
    msg = 'turbulento'
# imprimindo o resultado
print('O Re calculado foi de', format(Re, '.1f'), '\nLogo, o regime é', msg)

if msg == 'laminar':
    f1 = 64/Re   # caso Reynolds seja laminar, use a equação simplificada        
else:
    #---gerando dados para a construção de um gráfico de func(f) versus f
    func = []
    fs = np.linspace(0.0001 , 1.0, 500)      # criando um intervalo linear
    for fi in fs:
        func.append(-2.0*np.log10((epsilon/(D*3.7)) + 2.51/(Re*np.sqrt(fi))) 
        - 1.0/(np.sqrt(fi)))
    
    #---visualizando o comportamento de func(v) versus f
    p.clf()                                    # limpando a figura anterior
    p.plot(fs, func, 'g.-')                    # plotando o gráfico
    p.xlabel('f')                              # legenda do eixo X
    p.ylabel('func(f)')                        # legenda do eixo Y
    p.title('func(f) X f')                     # título
    p.legend(['func(f)'])                      # legenda do gráfico
    p.grid(color='k', linestyle='-', linewidth=0.1)#linhas de grade
    p.show()                                   # mostrar a figura
    p.pause(5)                                 # pausa para mostrar o gráfico
    print('\nContinuando a resolução do problema.')
    
    # entrando com a estimativa de f
    f1 = float(input('Entre com o valor da estimativa de f: '))
    
    # repita até que a condição seja alcançada
    while (erro >= 1e-15 and n < 1000):
        f = f1
        n += 1
        f1 = (-2.0*np.log10((epsilon/(D*3.7)) + 2.51/(Re*np.sqrt(f))))**(-2)
        erro = abs(f1 - f)

# cálculo do deltaP
deltaP = (f*L*ro*(v**2)/(2*D))/1000 #kPa

# vazão de líquido no tubo (m3/s)
Q = v*np.pi*(D/2)**2

#cálculo da potência do motor bomba necessária para suprir a queda de pressão
W = deltaP*Q

# imprimindo o resultado
print('O fator de atrito calculado foi de %.5f' %f1)
print('Para encontrar a solução, foram necessárias %i iterações' %n)
print('O erro absoluto foi de %.2e' %erro)
print('A queda de pressão no tubo foi de %.1f kPa' %deltaP)
print('Potência do motor bomba para suprir a queda de pressão é de %.2fkW' %W)

