# importando bibliotecas
from math import exp

# declaração das variáveis
T = 28.0                   # temperatura ambiente (°C)
DP = 19.15                 # pressão da alimentação do dessalinizador (atm)
Aw = 9e-4                  # constante de permeabilidade (kg/s.m2.atm)
As = 1.1e-7                # constante de permeabilidade do sal (m/s)
Rg = 0.08206               # constante dos gases (L·atm/K.mol)            
densi_agua = 996.236       # densidade da água (kg/m3 a 25°C)
Am = 7.2                   # área de membrana (m2)
volume_desejado = 1650.0   # volume de água permeada desejada (L/h)
Rec = 0.355                # recuperação do sistema
conc_desejada = 199.99     # concentração de sais desejada (g/l) no permeado
Kp = 0.99                  # constante devido ao tipo de membrana
Conc_permeado = 200        # estimativa inicial da concentração do permeado
n = 1                      # número de estágios
# concentração de sais em mg/L
conc_sais = [709.6, 809.1, 2268.1, 17.7, 0, 0.01, 0, 124.4, 342.1, 372.1, 
             6646.2, 0.06, 0.02, 2.72, 58.6]
# massa molar em g/mol
massa_molar = [40.08, 24.31, 22.99, 39.10, 26.98, 55.85, 0.17, 100.0869, 
               100.0869, 96.06, 35.45, 62.00, 46.01, 17.03, 60.08]

# concentração da alimentação (sólitos totais) (g/L)
Conc_aliment = sum(conc_sais)/1000 
#--Cálculo da pressão Osmótica da solução
fracao_massica =[]
# cálculo da fração mássica
for k in range(len(conc_sais)):
    fracao_massica.append(conc_sais[k]/(1000*Conc_aliment))
# número de espécies químicas envolvidas
num_elementos = len(conc_sais)

# concentração de polarização
beta = Kp*exp((2*Rec)/(2-Rec)) 

while Conc_permeado > conc_desejada and n < 5:
    print('\n----Resultados para o', n, '° estágio.-----')
    conc_molar = []
    for i in range(num_elementos):
        conc_molar.append(conc_sais[i]/(massa_molar[i]*1000))
    
    # concentração molar do sal na alimentação    
    m = sum(conc_molar)
    # pessão osmótica da alimentação (atm)            
    PO_aliment = 0.884*Rg*(T+273.15)*m   
    print('Pressão osmótica da alimentação:', format(PO_aliment, '.2f'), 'atm')
    
    #--Cálculo da pressão osmótica do permeado
    # assumindo que a concentração de sais no permeado é muito baixa, temos:
    PO_permeado = 0
    # cálculo da diferênça de pressão osmótica
    DPO = PO_aliment*beta - PO_permeado
    # cálculo do fluxo de água através da membrana (permeado)
    Nw = Aw*(DP - DPO)*3600             # kg de água/h.m2
    print('Fluxo mássico do permeado:', format(Nw, '.2f'), 'kg de água/h.m2')
    
    # a concentração de água no permeado cw2 é igual a densidade da água 
    # (claro que é considerando uma baixa concentração de sais!)
    cw2 = densi_agua                    # kg/m3 a 28°C
    B = Aw/(As*cw2)                     # 1/atm
    # a rejeição de sais na membrana é de:
    R = ((B*(DP - DPO))/(B*(DP - DPO)+1))*100
    print('Rejeição de sais calculada foi de:', format(R, '.1f'), '%')
    
    # a concentração de sais no permeado é de:
    Conc_permeado = Conc_aliment*(1 - R/100) #g/L
    print('Concentração no permeado:', format(Conc_permeado*1000,'.2f'),'mg/L')
    
    # o fluxo de sais através da membrana é de:
    Ns = As*(Conc_aliment*beta - Conc_permeado)*3600 #kg de sais/h.m2
    print('Fluxo (transmembrana):', format(Ns, '.3e'), 'kg de sais/h.m2')
    conc_sais = []
    for i in range(num_elementos):
        conc_sais.append(Conc_permeado*fracao_massica[i])
   
    # concentração da alimentação (g/L)
    Conc_aliment = sum(conc_sais)/1000 
    n += 1
print('\n--- Dados de projeto ---')

# cálculo do número de membranas
prod_por_membrana = (Nw/densi_agua)*1000*Am
print('Produção por membrana:', format(prod_por_membrana, '.4f'), 'L/h')
num_membranas = volume_desejado/prod_por_membrana
print('São necessários', format(round(num_membranas), '.1f'), 
      'elementos de membrana por estágio')

# considerando uma recuperação colicitada
vazao_Aliment = volume_desejado/Rec
print('Volume de alimentação:', format(vazao_Aliment, '.2f'), 'L/h')

