# importando bibliotecas
import numpy as np
import matplotlib.pyplot as p
# declaração de variáveis
MM = 28.01          # massa molar do CO (kg/kmol)
T = -50 + 273.15    # temperatura absoluta (K)
D = 0.3             # diâmetro do cilindro (m)
L = 1.8             # comprimento do cilindro (m)
Tc = 133            # temperatura crítica (K)
Pc = 35             # pressão crítica (bar)
R = 8314            # constante dos gases *N.m/kmol.K)
# listas vazias para o armazenamento das pressões calculadas
p1, p2, p3, p4 = [], [], [], []

# volume do reservatório
V = (np.pi*(D**2)/4)*L                           # volume do cilidro (m3)
m = np.linspace(0.1, 20, 70)                     # massa (kg de CO)
for mi in m:
    # cálculo do volume molar específico
    n = mi/MM                                    # qde de matéria (mols)
    v = V/n
    # Equação do gás Ideal
    p1i = (R*T/v)*(1/1e5)                        # (1bar/1e5N/m2)
    p1.append(p1i)
    # Equação de van der Waals
    a = ((27/64)*(R**2)*(Tc**2)/Pc)*(1/1e5)**2   # (m3/kmol)2
    b = (R*Tc)/(8*Pc)*(1/1e5)                    # m3/kmol
    p2i = ((R*T)/(v-b))*(1/1e5) - a/v**2
    p2.append(p2i)
    # Equação de Redlich-Kwong
    a1 = ((0.42748)*(R**2)*(Tc**(5/2))/Pc)*(1/1e5)**2  # bar(m6)K**0.5/kmol2
    b1 = (0.08664*(R*Tc)/Pc)*(1/1e5)                   # m3/kmol
    p3i = ((R*T)/(v-b1))*(1/1e5) - a1/(v*(v + b1)*(T**0.5))  # bar
    p3.append(p3i)
    # Equação de Peng-Robinson
    Tr = T/Tc                                   # temperatura reduzida
    alfa = 1/Tr**0.5                            # fator acêntrico
    p4i = ((R*T)/(v-b))*(1/1e5) - (a*alfa)/(v*(v + b) + b*(v - b))  #bar
    p4.append(p4i)
#---visualizando o comportamento de p(b\r) versus m (kg)
p.clf()                                         # limpando a figura anterior
p.plot(m, p1, 'b.', m, p2, ':k', m, p3, 'g.-', m, p4, 'r--')      
p.xlabel('m (kg)')                              # legenda do eixo X
p.ylabel('Pressões (bar)')                      # legenda do eixo Y
p.title('Pressões X m')                         # título
# legendas para as curvas
p.legend(['Gás Ideal', 'van der Waals', 'Redlich-Kwong', 'Peng-Robinson'])                        
p.grid(color='k', linestyle='-', linewidth=0.1) # linhas de grade
p.show()                                        # mostrar a figura

