# importando bilbiotecas
import matplotlib.pyplot as p
from numpy import log10, sqrt, arange
# declarando variáveis
Ka = 1.75e-5                   # constante de dissociação do ácido acético
Kw = 1e-14                     # produto iônico da água a 25°C
# dados do ácido
v_hAc = 50.0                   # volume da amostra (mL)
m_hAc = 0.02                   # concentração em quantidade de matéria (mol/L)
n_hAc = m_hAc*v_hAc            # quantidade de matéria (mol)
# dados da base
v_naoh = arange(0.0,16.5, 0.5) # lista com volumes de NaOH (mL)
m_naoh = 0.1                   # concentração em quantidade de matéria (mol/L)
# criação de uma lista vazia para armazenamento dos valores de pH
pH = []
# repetindo os cálculos para cada ml de NaOH da lista v_naoH
for i in range(len(v_naoh)):
    n_naoh = m_naoh*v_naoh[i]
    # 1° teste: quando a amostra ainda é pura   
    if n_naoh == 0.0:
        h = sqrt(Ka*m_hAc)                                  #Eq.8.12
        pH.append(-log10(h))                                #Eq.8.13
    # 2° teste: antes de alcançar o ponto de equivalência
    elif n_naoh < n_hAc:
        mt = (n_hAc - n_naoh)/(v_hAc + v_naoh[i])           #Eq.8.15
        ms = n_naoh/(v_hAc + v_naoh[i])                     #Eq.8.16
        ph = -log10(Ka) - log10(mt/ms)                      #Eq.8.19
        pH.append(ph)
    # 3° teste: no ponto de equivalência
    elif n_naoh == n_hAc:
        ms = n_hAc/(v_hAc + v_naoh[i])                      #Eq.8.16
        oh = sqrt((Kw/Ka)*ms)                               #Eq.8.21
        pH.append(-log10(Kw/oh))                            #Eq.8.22
    # 4° teste: após o ponto de equivalência    
    else:
        mt = (n_naoh - n_hAc)/(v_hAc + v_naoh[i])           #Eq.8.23
        ms = n_hAc/(v_hAc + v_naoh[i])                      #Eq.8.25
        oh1 = sqrt((Kw/Ka)*ms)                              #Eq.8.26
        oh = mt + oh1                                       #Eq.8.27
        pH.append(-log10(Kw/oh))                            #Eq.8.22    
#---visualizando o comportamento do pH em um gráfico
p.clf()                                         # limpando figuras anteriores
p.plot(v_naoh, pH, 'b:')                        # plotando o gráfico
p.xlabel('NaOH (ml)')                           # legenda do eixo X
p.ylabel('pH')                                  # legenda do eixo Y
p.title('Curva de Neutralização')               # título
p.legend(['pH'])                                # legenda do gráfico
p.grid(color='k', linestyle='-', linewidth=0.1) # linhas de grade
p.show()                                        # mostrar a figura

